# A PyFyre App
Get started by modifying the [src/index.py](src/index.py).

Learn PyFyre by reading the [documentation](https://pyfyre.netlify.app/). It is also advisable to learn [Brython](https://www.brython.info/) alongside PyFyre as it is built on top of Brython.

### Scripts
```
pyfyre run
  Run your PyFyre project in development mode.

pyfyre build
  Build your PyFyre project for production deployment.
```

### Deployment
Run `pyfyre build`. The build files are saved in the [build](build) directory so you can just serve or deploy that directory to the web.

### Links
- [PyPI](https://pypi.org/project/pyfyre/)
- [Repository](https://github.com/pyfyre/pyfyre)
- [Documentation](https://pyfyre.netlify.app/)
- [Facebook Page](https://www.facebook.com/pyfyreframework/)
